raytraverse.SpaceMapper
==========================================================

.. autoclass:: raytraverse.spacemapper.SpaceMapper
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
